@@ -42,6 +42,11 @@ KineticList::KineticList(Orientation orientation, QSizeF size, QGraphicsWidget *
     p.setColor(QPalette::Base, Qt::transparent);
     _view->viewport()->setPalette(p);
 
+    _view->setViewportUpdateMode(QGraphicsView::BoundingRectViewportUpdate);
+    _view->setOptimizationFlags(QGraphicsView::DontSavePainterState);
+    _view->setFrameShape(QFrame::NoFrame);
+    _view->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+
     // Kinetic scroll
     #ifdef Q_WS_MAEMO_5
         QAbstractKineticScroller *scroller = _view->property("kineticScroller").value<QAbstractKineticScroller *>();
