@@ -96,7 +96,7 @@ public slots:
 
 signals:
     void enterPressed(void);
-    void textChanged(void);
+    void textChanged(QString);
 
 private:
     void _createCounter(void);
