@@ -29,15 +29,17 @@ Loader::Loader(QGraphicsWidget *parent, QPointF pos)
         : TwitterApplicationItem(parent),
         m_pos(pos)
 {
+    setGeometry(0,0,800,480);
 
     _background = new QGraphicsRectItem(QRect(0, 0, 800, 480), this);
     _background->setBrush(Qt::black);
-    _background->setOpacity(0.0);
+    _background->setOpacity(0.5);
+    _background->setZValue(1.0);
 
     _image = new TwitterApplicationItem(this);
     _image->setZValue(1.0);
     /* This is necessary to set loader image center used by rotate function */
-    _image->setTransformOriginPoint(QPointF(18, 18));
+    _image->setTransformOriginPoint(QPointF(24, 24));
 
     QGraphicsPixmapItem *img = new QGraphicsPixmapItem(_image);
     img->setPixmap(QPixmap(":images/resources/preloader.png"));
@@ -62,7 +64,6 @@ Loader::~Loader()
     if (_image) {
         delete _image;
     }
-    qDebug() << "~ " << __PRETTY_FUNCTION__;
 }
 
 /*!
@@ -71,7 +72,6 @@ Loader::~Loader()
  */
 void Loader::startEntryAnimation(void)
 {
-    qDebug() << "+ " << __PRETTY_FUNCTION__;
     setEntryAnimation();
     _entryAnimation->start();
 }
@@ -161,12 +161,7 @@ void Loader::setExitAnimation(void)
     _exitAnimation->addAnimation(_animOpacity);
 }
 
-/*!
- * \brief Gets loader background rectangle.
- * \return _background returns loader background rectangle.
- */
-QGraphicsRectItem *Loader::getBackground()
+void Loader::mousePressEvent(QGraphicsSceneMouseEvent *event)
 {
-    return _background;
+    Q_UNUSED(event);
 }
-
