@@ -92,7 +92,7 @@ OauthWizard::OauthWizard(QGraphicsWidget *parent)
     _pinEntry = new LineEdit(LineEdit::Short,this);
     _pinEntry->setPos((_bg->boundingRect().width() - _pinEntry->boundingRect().width())/2,250);
     _pinEntry->setMaxLength(7);
-    connect(_pinEntry, SIGNAL(textChanged()),SLOT(_enableButton()));
+    connect(_pinEntry, SIGNAL(textChanged(QString)),SLOT(_enableButton()));
 
     // Validate Button
     _validateButton = new TwitterButton(TwitterButton::Generic,"Validate PIN",this);
