@@ -150,7 +150,7 @@ void Tweet::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWi
     else
         painter->setBrush(QColor(246, 253, 255));
 
-    painter->drawRoundedRect(0, 0, rect().width(), rect().height(),2,2);
+    painter->drawRoundedRect(0, 0, rect().width()-10, rect().height(),2,2);
     painter->setRenderHint(QPainter::Antialiasing);
 
     // Avatar Rect
