@@ -22,6 +22,15 @@
 
 #include "backend.h"
 
+/*! \namespace Connection Contains types of connections.
+  */
+namespace Connection
+{
+    enum ConnectionType { VerifyCredentials, Update, GetFriendsTimeline, RemoveStatus,
+                          AddFavorite, RemoveFavorite, addFriendship, RemoveFriendship,
+                          SendDirectMessage, GetMentions };
+}
+
 Backend *Backend::_instance = 0;
 
 /*!
@@ -43,7 +52,8 @@ Backend *Backend::getInstance(void)
  */
 Backend::Backend()
     : twitterapi( new TwitterAPI ),
-    friendsPage(1)
+    friendsPage(1),
+    mentionsPage(1)
 {
 //    QSettings settings("Zagaia","TweeGo");
 //        settings.beginGroup("PROXY");
@@ -66,6 +76,7 @@ Backend::Backend()
 
 void Backend::_deleteEntry(quint64 id)
 {
+    userInformations.statusesCount -= 1;
     emit deletedTweet(id);
 }
 
@@ -80,26 +91,33 @@ void Backend::_parseEntries(EntryList entries)
     int lastConn = conns.at(0);
     conns.removeAt(0);
 
-    switch(lastConn)
-    {
-        case Connection::GetFriendsTimeline:
-            _tweets = entries;
-            emit gotFriendsTimeline();
-            break;
-
-        case Connection::Update:
-            _tweets = entries;
-            emit updatePosted();
-            break;
-    }
-
     foreach( const Entry &entry, entries ) {
         if(entry.isOwn)
             userInformations = entry.userInfo;
     }
 
+    _addNewTweets(entries);
 
+    switch(lastConn)
+    {
+        case Connection::GetFriendsTimeline:
+            emit gotFriendsTimeline();
+            break;
 
+        case Connection::Update:
+            emit updatePosted();
+            break;
+
+        case Connection::GetMentions:
+            emit gotMentions();
+            break;
+    }
+}
+
+void Backend::_addNewTweets(EntryList entries)
+{
+    //TODO: remove duplicated tweets, maybe QMap<int,Entry*>
+    _tweets = entries;
 }
 
 /*!
@@ -136,6 +154,11 @@ void Backend::getTimeline(Timeline::TimelineType type)
         case Timeline::Public:
             twitterapi->publicTimeline();
             break;
+        case Timeline::Mentions:
+            conns << Connection::GetMentions;
+            twitterapi->mentions(mentionsPage);
+            mentionsPage++;
+            break;
     }
 }
 
@@ -255,14 +278,6 @@ bool Backend::updateProfileImage(QString image)
     return false;
 }
 
-/*!
- * \brief Try to get a mentions timeline from the twitter.
- */
-void Backend::getMentions()
-{
-    // TODO
-}
-
 /*!
  * \brief Sets which mentions timeline page to download.
  * \param page Page number.
