@@ -32,22 +32,17 @@ TimelineCtrl::TimelineCtrl(QGraphicsScene *scene)
 
     _timelineView = new TimelineView();
 
-//    isFollowing = true;
-//    updateTimeline = false;
-//    isGPS = false;
-//    pageToDownload = 2;
-//    mentionsPageToDownload = 2;
-//    addHome = true;
-//    addMentions = true;
-
     connect(_timelineView, SIGNAL(postUpdate(void)), this, SLOT(_postNewUpdate(void)));
 //    connect(_timelineView, SIGNAL(favorite(QString, bool)), this, SLOT(_handleFavorite(QString, bool)));
     connect(_timelineView, SIGNAL(deleteTweet(quint64)), this, SLOT(_handleDeleteTweet(quint64)));
-//    connect(_timelineView, SIGNAL(logout()), this, SLOT(_logout()));
+    connect(_timelineView, SIGNAL(getTimeline(Timeline::TimelineType)),
+            Backend::getInstance(), SLOT(getTimeline(Timeline::TimelineType)));
 //    connect(_timelineView, SIGNAL(unfollow(QString, bool)), this, SLOT(_handleFriendship(QString, bool)));
     connect(_timelineView, SIGNAL(done()),this, SLOT(deleteLater()));
-    connect(_timelineView, SIGNAL(refresh()), SLOT(_refreshTimeline()));
-    connect(_timelineView, SIGNAL(moreTweets()), SLOT(_moreTweets()));
+    connect(_timelineView, SIGNAL(homeRefresh()), SLOT(_refreshHome()));
+    connect(_timelineView, SIGNAL(mentionsRefresh()), SLOT(_refreshMentions()));
+    connect(_timelineView, SIGNAL(moreHomeTweets()), SLOT(_moreHomeTweets()));
+    connect(_timelineView, SIGNAL(moreMentions()), SLOT(_moreMentions()));
 //    connect(_timelineView, SIGNAL(changeAvatar(QString)), this, SLOT(_updateProfileImage(QString)));
 
 //    connect(_timelineView, SIGNAL(showLocationDialog()), this, SLOT(_dialogLocation()));
@@ -59,7 +54,8 @@ TimelineCtrl::TimelineCtrl(QGraphicsScene *scene)
     showView();
 
     Backend::getInstance()->getTimeline(Timeline::Friends);
-    connect(Backend::getInstance(), SIGNAL(gotFriendsTimeline()), SLOT(_populateTimeline()));
+    connect(Backend::getInstance(), SIGNAL(gotFriendsTimeline()), SLOT(_populateHome()));
+    connect(Backend::getInstance(), SIGNAL(gotMentions()), SLOT(_populateMentions()));
     connect(Backend::getInstance(), SIGNAL(updatePosted()), SLOT(_updatePosted()));
     connect(Backend::getInstance(), SIGNAL(deletedTweet(quint64)),SLOT(_deletedTweet(quint64)));
 }
@@ -149,17 +145,6 @@ void TimelineCtrl::_postNewUpdate()
 //        _timelineView->m_mentionsTimeline->moreButtonEnable(true);
 }
 
-/*!
- *\brief This function handles any connection errors that might occur.
- *\param message message that will appear on the messagebox.
- */
-void TimelineCtrl::_connectionError(QString message)
-{
-//    dialog = new DialogView(DialogView::Error, message);
-//    _scene->addItem(dialog);
-//    _timelineView->connectionError();
-}
-
 /*!
  *\brief This function provides an error messagebox to any error that might occur.
  *\param message message that will appear on the messagebox.
@@ -271,19 +256,6 @@ void TimelineCtrl::_logout()
 //    _scene->addItem(dialog);
 }
 
-/*!
- * \brief Clears all information on the current list
- * and creates a new list with updated information.
- */
-void TimelineCtrl::_updateTimeline()
-{
-//    qDebug() << "+ " << __PRETTY_FUNCTION__;
-
-//    Backend::getInstance()->verifyCredentials();
-//    _timelineView->updateTopBar();
-//    _timelineView->endLoader();
-}
-
 /*!
  * \brief Updates the user avatar.
  * \param image User's new image.
@@ -340,7 +312,7 @@ void TimelineCtrl::_handleGPSLocation()
 //    isGPS = true;
 }
 
-void TimelineCtrl::_populateTimeline(void)
+void TimelineCtrl::_populateHome(void)
 {
     EntryList entries = Backend::getInstance()->tweets();
 
@@ -349,7 +321,20 @@ void TimelineCtrl::_populateTimeline(void)
         Tweet *tweet = new Tweet(entry,NULL);
         _timelineView->_homeTimeline->addToList(tweet);
     }
-    _timelineView->addMoreButton();
+    _timelineView->addMoreButton(Timeline::Friends);
+    _timelineView->endLoader();
+}
+
+void TimelineCtrl::_populateMentions(void)
+{
+    EntryList entries = Backend::getInstance()->tweets();
+
+    foreach( const Entry &entry, entries )
+    {
+        Tweet *tweet = new Tweet(entry,NULL);
+        _timelineView->_mentionsTimeline->addToList(tweet);
+    }
+    _timelineView->addMoreButton(Timeline::Mentions);
     _timelineView->endLoader();
 }
 
@@ -364,24 +349,36 @@ void TimelineCtrl::_updatePosted(void)
     }
     _timelineView->m_statusId = 0;
     _timelineView->clearText();
+    _timelineView->updateTopBar();
     _timelineView->endLoader();
 }
 
-void TimelineCtrl::_refreshTimeline(void)
+void TimelineCtrl::_refreshHome(void)
 {
     _timelineView->_homeTimeline->clearList();
-    _timelineView->startLoader();
     Backend::getInstance()->setFriendsPage(1);
     Backend::getInstance()->getTimeline(Timeline::Friends);
 }
 
-void TimelineCtrl::_moreTweets(void)
+void TimelineCtrl::_moreHomeTweets(void)
 {
-    _timelineView->startLoader();
     Backend::getInstance()->getTimeline(Timeline::Friends);
 }
 
+void TimelineCtrl::_refreshMentions(void)
+{
+    _timelineView->_mentionsTimeline->clearList();
+    Backend::getInstance()->setMentionsPage(1);
+    Backend::getInstance()->getTimeline(Timeline::Mentions);
+}
+
+void TimelineCtrl::_moreMentions(void)
+{
+    Backend::getInstance()->getTimeline(Timeline::Mentions);
+}
+
 void TimelineCtrl::_deletedTweet(quint64 id)
 {
+    _timelineView->updateTopBar();
     _timelineView->tweetDeleted(id);
 }
