@@ -55,16 +55,13 @@ public:
     void createUi(void);
     void setUpdateMessage(const QString &message);
     void updateTopBar(void);
-    int containsUrl(QString message);
     QString getUpdateMessage(void);
     bool getHome(void);
-    void addMoreButton(void);
+    void addMoreButton(Timeline::TimelineType);
     void tweetDeleted(quint64);
     void clearText(void);
 
 public slots:
-    void connectionError(void);
-    void urlShorteningError(QString);
     void endLoader(void);
     void startLoader(void);
     void getIPCoordinates(void);
@@ -83,38 +80,45 @@ signals:
     void changeAvatar(QString);
     void showLocationDialog(void);
     void gotGPS(void);
-    void refresh(void);
+    void homeRefresh(void);
+    void mentionsRefresh(void);
     void loadMap(void);
-    void moreTweets(void);
+    void moreHomeTweets(void);
+    void moreMentions(void);
+    void getTimeline(Timeline::TimelineType);
 
 private slots:
     void _deleteLoader(void);
-    void _emitPostUpdate(void);
+    void _enableTweetButton(QString);
     void _handleNewMessage(QString newMessage);
     void _handleReply(QString newMessage, quint64 statusId);
     void _createTweetInfo(Tweet *tweet);
     void _backToLogin(void);
+    void _emitRefresh(void);
+    void _emitPostUpdate(void);
+    void _emitMoreTweets(void);
     void _emitUnfollow(QString, bool);
     void _emitDelete(quint64, Tweet*);
     void _emitFavorite(QString, bool);
     void _emitChangeAvatar(QString);
     void _createTimeline(void);
-    void _moreButtonHome(void);
-    void _moreButtonMentions(void);
-
+    void _toHome(void);
+    void _toMentions(void);
     void _showIpLocationInfo(double latitude, double longitude);
-
     void _openTwitPic(TwitPic::Services);
     void _closeTwitPic(void);
     void _deleteTwitPic(void);
 
 private:
     QAbstractAnimation *_createEntryAnimation(void);
-    QAbstractAnimation *_createExitAnimation();
+    QAbstractAnimation *_createExitAnimation(void);
     void _createEntry(void);
     void _createButtons(void);
     void _createTopBar(void);
     void _createSettings(void);
+    void _moveToLeft(KineticList*, KineticList*);
+    void _moveToRight(KineticList*, KineticList*);
+    void _moveTimelines(KineticList*, KineticList*);
     void _addOpacityAnim(QParallelAnimationGroup *anim,
                          TwitterApplicationItem *item,
                          int delay);
@@ -126,9 +130,15 @@ private:
 private:
     QAbstractAnimation *_exitAnim;
     QAbstractAnimation *_entryAnim;
+    KineticList *timelineOnScreen;
     Loader *_loader;
     LineEdit *_entryUpdate;
     Tweet *m_deleteTweet;
+    QPointF leftPos;
+    QPointF centerPos;
+    QPointF rightPos;
+    QList<KineticList*> _timelines;
+    QList<bool> _downloadedTimelines;
 
 public:
     quint64 m_statusId;
@@ -140,6 +150,7 @@ public:
     UrlShortener *_urlShortener;
     IpLocation *_ipLocation;
     KineticList *_homeTimeline;
+    KineticList *_mentionsTimeline;
     TimelineSettings *_settingsDialog;
     TwitPic *m_twitPic;
 
