@@ -27,8 +27,10 @@
 TwitPic::TwitPic(QGraphicsWidget *parent) :
         TwitterApplicationItem(parent)
 {
-    m_manager = new QNetworkAccessManager( this );
-    connect(m_manager, SIGNAL(finished(QNetworkReply*)), this, SLOT(handleNetworkRequest(QNetworkReply*)));
+    m_twitPicManager = new QNetworkAccessManager( this );
+    m_tweetPhotoManager = new QNetworkAccessManager( this );
+    connect(m_twitPicManager, SIGNAL(finished(QNetworkReply*)), this, SLOT(handleTwitPicRequest(QNetworkReply*)));
+    connect(m_tweetPhotoManager, SIGNAL(finished(QNetworkReply*)), this, SLOT(handleTweetPhotoRequest(QNetworkReply*)));
 
     setGeometry(0, 0, 800, 480);
     setMinimumSize(800, 480);
@@ -46,7 +48,7 @@ TwitPic::~TwitPic()
  * \brief This function sends the request to download the profile image
  * \param Url the url where the profile image is hosted
  */
-void TwitPic::download(QString Url)
+void TwitPic::downloadTwitPic(QString Url)
 {
     qDebug() << "+ " << __PRETTY_FUNCTION__;
 
@@ -55,14 +57,14 @@ void TwitPic::download(QString Url)
 
     QNetworkRequest request;
     request.setUrl(Url);
-    m_manager->get(request);
+    m_twitPicManager->get(request);
 }
 
 /*!
  * \brief This function handles the reply and loads the image
  * \param reply The network reply
  */
-void TwitPic::handleNetworkRequest(QNetworkReply *reply)
+void TwitPic::handleTwitPicRequest(QNetworkReply *reply)
 {
     qDebug() << "+ " << __PRETTY_FUNCTION__;
 
@@ -84,9 +86,77 @@ void TwitPic::parseHtml(QString html)
     a = html.section("img src=\"", 2, 2);
     QStringList stringList = a.split("\"");
 
+    m_isTweetPhoto = false;
     downloadImage(stringList[0]);
 }
 
+/*!
+ * \brief This function sends the request to download the profile image
+ * \param Url the url where the profile image is hosted
+ */
+void TwitPic::downloadTweetPhoto(QString Url)
+{
+    qDebug() << "+ " << __PRETTY_FUNCTION__;
+
+    m_isImage = false;
+    m_paintImage = false;
+
+    QString apiUrl = "http://api.tweetphoto.com/api/tpapi.svc/photos/";
+
+    QString tweetPhotoId;
+    tweetPhotoId = Url.section("/", 3, 3);
+
+    QNetworkRequest request;
+    request.setUrl(apiUrl + tweetPhotoId);
+    m_tweetPhotoManager->get(request);
+}
+
+/*!
+ * \brief This function handles the reply and loads the image
+ * \param reply The network reply
+ */
+void TwitPic::handleTweetPhotoRequest(QNetworkReply *reply)
+{
+    qDebug() << "+ " << __PRETTY_FUNCTION__;
+
+    if(m_isImage) {
+        if(!m_image.load(reply,0))
+            m_image = QImage();
+        m_paintImage = true;
+        update();
+    }
+    else
+        parseTweetPhotoXml(QString(reply->readAll()));
+
+    reply->deleteLater();
+}
+
+void TwitPic::parseTweetPhotoXml(QString xml)
+{
+    QDomDocument doc;
+    QDomNodeList nodeList;
+
+    doc.setContent(xml);
+    nodeList = doc.elementsByTagName("Photo");
+
+    for(int i=0; i<nodeList.count(); i++)
+    {
+            QDomElement node;
+
+            node = nodeList.at(i).toElement();
+
+            QString bigImageUrl = node.namedItem("BigImageUrl").toElement().text();
+            QString thumbnailurl = node.namedItem("ThumbnailUrl").toElement().text();
+            m_message = node.namedItem("Message").toElement().text();
+
+            m_imageUrlList.append(bigImageUrl);
+            m_imageUrlList.append(thumbnailurl);
+            m_imageUrlList.append(m_message);
+    }
+    m_isTweetPhoto = true;
+    downloadImage(m_imageUrlList[0]);
+}
+
 void TwitPic::downloadImage(QString imageUrl)
 {
     m_isImage = true;
@@ -99,7 +169,11 @@ void TwitPic::downloadImage(QString imageUrl)
 
     request.setUrl(newUrl);
     qDebug() << newUrl;
-    m_manager->get(request);
+
+    if(!m_isTweetPhoto)
+        m_twitPicManager->get(request);
+    else
+        m_tweetPhotoManager->get(request);
 }
 
 /*!
@@ -120,6 +194,25 @@ void TwitPic::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, Q
         m_imageScaled = m_image.scaled(760, 440, Qt::KeepAspectRatio);
         painter->drawImage((800 - m_imageScaled.width()) / 2, 20, m_imageScaled);
     }
+
+    /* Draw Message */
+    if (!m_message.isEmpty()) {
+
+        QFont font;
+        font.setFamily("Nokia Sans");
+        font.setStyle(QFont::StyleNormal);
+        font.setStyleStrategy(QFont::PreferAntialias);
+        font.setPixelSize(22);
+        font.setWeight(QFont::Normal);
+        painter->setFont(font);
+
+        QRectF messageRect(QRectF(0 , m_imageScaled.rect().bottom() - 20,
+                                  800, 40 + 20));
+
+        painter->drawRoundedRect(messageRect, 5, 5);
+        painter->setPen(QColor(Qt::white));
+        painter->drawText(messageRect, Qt::TextWordWrap | Qt::AlignCenter, m_message);
+    }
 }
 
 /*!
@@ -127,8 +220,6 @@ void TwitPic::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, Q
  */
 void TwitPic::mousePressEvent(QGraphicsSceneMouseEvent *event)
 {
-//    if(contains(event->pos()))
-//        update();
 }
 
 /*!
@@ -151,7 +242,11 @@ void TwitPic::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
 
         if(ret == QMessageBox::Save) {
             QFileDialog dialog;
-            QString fileName = dialog.getSaveFileName(0, tr("Save File"), "/home/user/MyDocs/.images/untitled.jpg", tr("Images (*.png *.gif *.jpg)"));
+            #ifdef Q_WS_MAEMO_5
+            QString fileName = dialog.getSaveFileName(0, tr("Save File"), "/home/user/.images/untitled.jpg", tr("Images (*.png *.gif *.jpg)"));
+            #else
+            QString fileName = dialog.getSaveFileName(0, tr("Save File"), "/home/roda/untitled.jpg", tr("Images (*.png *.gif *.jpg)"));
+            #endif
 
             if(fileName != NULL)
                     m_image.save(fileName);
